"Modern-DI-FastAPI"
==
[![Test Coverage](https://codecov.io/gh/modern-python/modern-di-fastapi/branch/main/graph/badge.svg)](https://codecov.io/gh/modern-python/modern-di-fastapi)
[![Supported versions](https://img.shields.io/pypi/pyversions/modern-di-fastapi.svg)](https://pypi.python.org/pypi/modern-di-fastapi)
[![downloads](https://img.shields.io/pypi/dm/modern-di-fastapi.svg)](https://pypistats.org/packages/modern-di-fastapi)
[![GitHub stars](https://img.shields.io/github/stars/modern-python/modern-di-fastapi)](https://github.com/modern-python/modern-di-fastapi/stargazers)

Integration of [Modern-DI](https://github.com/modern-python/modern-di) to FastAPI

Usage example: [fastapi-sqlalchemy-template](https://github.com/modern-python/fastapi-sqlalchemy-template)

## 📚 [Documentation](https://modern-di.readthedocs.io)
